PIDSIM reference models package
===============================

.. warning::

   This package just have the python modules, not any GUI.

This package implements a basic set of reference models for the simulation
of PID controllers, using PIDSIM.

If you need some help with the use, or can help with the development,
please contact the author via email or visit our project website:

http://pidsim.org/

All the help is welcome! :)


Basic installation
~~~~~~~~~~~~~~~~~~

To install, type::

    # python setup.py install

or use pip::

    # pip install pidsim-models

